==> home-library-jcr-1.0.0-sources.jar: org/gcube/portlets/user/homelibrary/jcr/workspace/folder/items/JCRFile.java <==
package org.gcube.portlets.user.homelibrary.jcr.workspace.folder.items;



import java.io.InputStream;

import javax.jcr.Binary;
import javax.jcr.Node;
import javax.jcr.RepositoryException;
import javax.jcr.Session;

import org.gcube.portlets.user.homelibrary.home.exceptions.InternalErrorException;
import org.gcube.portlets.user.homelibrary.home.workspace.folder.items.File;
import org.gcube.portlets.user.homelibrary.jcr.content.JCRRepository;
import org.gcube.portlets.user.homelibrary.util.MimeTypeUtil;

public class JCRFile implements File {
		
	private static final String MIME_TYPE = "jcr:mimeType";
	protected static final String DATA 	  = "jcr:data";
	
	protected String nodeId;
	private final String mimeType;
	private final long size;
	
	public JCRFile(Node node) throws RepositoryException  {
		
		this.nodeId = node.getIdentifier();
		this.mimeType = node.getProperty(MIME_TYPE).getString();
		this.size = node.getProperty(DATA).getBinary().getSize();
	}
	
	public JCRFile(Node node, String mimeType, InputStream data) throws RepositoryException {
	
		Binary binary = node.getSession().getValueFactory().createBinary(data);
		this.size = binary.getSize();
		node.setProperty(DATA,binary);
		node.setProperty(MIME_TYPE, mimeType);
		this.mimeType = mimeType;
	}
	
	public void save(Node node) throws RepositoryException {
		this.nodeId = node.getIdentifier();
	}
	
	public JCRFile(Node node, InputStream data) throws RepositoryException {
		this(node, MimeTypeUtil.getMimeType(data), data);
	}

	@Override
	public String getName() throws InternalErrorException {
		Session session = JCRRepository.getSession();
		try {
			Node node = session.getNodeByIdentifier(nodeId);
			return node.getName();
		} catch (RepositoryException e) {
			throw new InternalErrorException(e);
		} finally {
			session.logout();
		}
	}

	@Override
	public String getMimeType() {
		return mimeType;
	}

	@Override
	public InputStream getData() throws InternalErrorException {
	
		Session session = JCRRepository.getSession();
		try {
			Node node = session.getNodeByIdentifier(nodeId);
			return node.getProperty(DATA).getBinary().getStream();
		} catch (RepositoryException e) {
			throw new InternalErrorException(e);
		} finally {
			session.logout();
		}
	}


	@Override
	public long getLength() throws InternalErrorException {
		return size;
	}


}

==> home-library-jcr-1.0.0-20120905.022836-21-sources.jar: org/gcube/portlets/user/homelibrary/jcr/workspace/folder/items/JCRFile.java <==
package org.gcube.portlets.user.homelibrary.jcr.workspace.folder.items;



import java.io.InputStream;

import javax.jcr.Binary;
import javax.jcr.Node;
import javax.jcr.RepositoryException;
import javax.jcr.Session;

import org.gcube.portlets.user.homelibrary.home.exceptions.InternalErrorException;
import org.gcube.portlets.user.homelibrary.home.workspace.folder.items.File;
import org.gcube.portlets.user.homelibrary.jcr.content.JCRRepository;
import org.gcube.portlets.user.homelibrary.util.MimeTypeUtil;

public class JCRFile implements File {
		
	private static final String MIME_TYPE = "jcr:mimeType";
	protected static final String DATA 	  = "jcr:data";
	
	protected String nodeId;

	
	public JCRFile(Node node) throws RepositoryException  {
		this.nodeId = node.getIdentifier();
	}
	
	public JCRFile(Node node, String mimeType, InputStream data) throws RepositoryException {
	
		Binary binary = node.getSession().getValueFactory().createBinary(data);
		node.setProperty(DATA,binary);
		node.setProperty(MIME_TYPE, mimeType);
	}
	
	public void save(Node node) throws RepositoryException {
		this.nodeId = node.getIdentifier();
	}
	
	public JCRFile(Node node, InputStream data) throws RepositoryException {
		this(node, MimeTypeUtil.getMimeType(data), data);
	}

	@Override
	public String getName() throws InternalErrorException {
		Session session = JCRRepository.getSession();
		try {
			Node node = session.getNodeByIdentifier(nodeId);
			return node.getName();
		} catch (RepositoryException e) {
			throw new InternalErrorException(e);
		} finally {
			session.logout();
		}
	}

	@Override
	public String getMimeType() {
		Session session = null;
		try {
			session = JCRRepository.getSession();
			Node node = session.getNodeByIdentifier(nodeId);
			return node.getProperty(MIME_TYPE).getString();
		} catch (Exception e) {
			throw new RuntimeException(e);
		} finally {
			session.logout();
		}
	}

	@Override
	public InputStream getData() throws InternalErrorException {
	
		Session session = JCRRepository.getSession();
		try {
			Node node = session.getNodeByIdentifier(nodeId);
			return node.getProperty(DATA).getBinary().getStream();
		} catch (RepositoryException e) {
			throw new InternalErrorException(e);
		} finally {
			session.logout();
		}
	}


	@Override
	public long getLength() throws InternalErrorException {
		Session session = null;
		try {
			session = JCRRepository.getSession();
			Node node = session.getNodeByIdentifier(nodeId);
			return node.getProperty(DATA).getBinary().getSize();
		} catch (Exception e) {
			throw new RuntimeException(e);
		} finally {
			session.logout();
		}
	}


}
